@@ -6,13 +6,13 @@ use warnings;
 
 BEGIN {
 	$MooX::ClassAttribute::AUTHORITY = 'cpan:TOBYINK';
-	$MooX::ClassAttribute::VERSION   = '0.004';
+	$MooX::ClassAttribute::VERSION   = '0.005';
 }
 
 use Carp;
 use Moo ();
 use Moo::Role ();
-use MooX::CaptainHook -all;
+use MooX::CaptainHook qw( on_application on_inflation is_role );
 
 BEGIN { *ROLE = \%Role::Tiny::INFO }
 our %ROLE;
